@@ -2,25 +2,25 @@ use strict;
 use warnings;
 package Sque;
 {
-  $Sque::VERSION = '0.004';
+  $Sque::VERSION = '0.005';
 }
 use Any::Moose;
 use Any::Moose '::Util::TypeConstraints';
-use Net::STOMP::Client;
+use Net::Stomp;
 
 use Sque::Job;
 use Sque::Worker;
 
 # ABSTRACT: Background job processing based on Resque, using Stomp
 
-subtype 'Sugar::Stomp' => as class_type('Net::STOMP::Client');
+subtype 'Sugar::Stomp' => as class_type('Net::Stomp');
 
 coerce 'Sugar::Stomp'
     => from 'Str'
     => via {
         my ( $host, $port ) = split /:/;
-        my $stomp = Net::STOMP::Client->new( host => $host, port => $port );
-        $stomp->connect();
+        my $stomp = Net::Stomp->new({ hostname => $host, port => $port });
+        $stomp->connect;
         return $stomp;
     };
 
@@ -29,7 +29,7 @@ has stomp => (
     lazy => 1,
     coerce => 1,
     isa => 'Sugar::Stomp',
-    default => sub { Net::STOMP::Client->new->connect },
+    default => sub { Net::Stomp->new->connect },
 );
 
 has namespace => ( is => 'rw', default => sub { 'sque' });
@@ -50,11 +50,11 @@ sub push {
         $job = $self->new_job($job) unless ref $job eq 'Sque::Job';
     }
 
-    $self->stomp->send(
+    $self->stomp->send( {
         persistent => 'true',
         destination => $self->key( $queue ),
         body => $job->encode,
-    );
+    } );
 }
 
 sub pop {
@@ -64,7 +64,7 @@ sub pop {
 
     $self->new_job({
         frame => $frame,
-        queue => $frame->header('destination'),
+        queue => $frame->destination,
     });
 }
 
@@ -72,7 +72,7 @@ sub new_job {
     my ( $self, $job ) = @_;
 
     if ( $job && ref $job && ref $job eq 'HASH' ) {
-         return Sque::Job->new({ sque => $self, %$job });
+        return Sque::Job->new({ sque => $self, %$job });
     }
     elsif ( $job ) {
         return Sque::Job->new({ sque => $self, payload => $job });
@@ -99,7 +99,7 @@ Sque - Background job processing based on Resque, using Stomp
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -123,8 +123,8 @@ You can also send by just using:
     });
 
 In this case, the queue will be set automatically automatically to the
-job class name with colons replaced with hyphens, which in this
-case would be 'My-Task'.
+job class name with colons removed, which in this
+case would be 'MyTask'.
 
 Additionally, the L<sque> command-line tool can be used to send messages:
 
